@@ -5,14 +5,14 @@ import pooch
 
 
 audio_file = pooch.retrieve(
-    url="https://www2.cs.uic.edu/~i101/SoundFiles/preamble10.wav",
-    known_hash="md5:fd76bc5fd34ffd93837490c3b946a99d",
+    url="https://project-test-data-public.s3.amazonaws.com/test_audio.m4a",
+    known_hash="md5:77d8b60c54dffbb74d48c4a65cd59591",
 )
 
 
 def test_process():
     """Test whisper processing of audio."""
-    result = whisper.process(audio_file=audio_file)
+    result = whisper.process(audio_file=Path(audio_file))
     assert isinstance(result, Dict)
     for seg in result["segments"]:
         assert "start" in seg
